@@ -1,20 +1,8 @@
-/**********************************************************************************
- *   Copyright (C) 2008 by Carlo Segato <brandon.ml@gmail.com>                    *
- *                                                                                *
- *   This library is free software; you can redistribute it and/or                *
- *   modify it under the terms of the GNU Lesser General Public                   *
- *   License as published by the Free Software Foundation; either                 *
- *   version 2.1 of the License, or (at your option) any later version.           *
- *                                                                                *
- *   This library is distributed in the hope that it will be useful,              *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of               *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU            *
- *   Lesser General Public License for more details.                              *
- *                                                                                *
- *   You should have received a copy of the GNU Lesser General Public             *
- *   License along with this library.  If not, see <http://www.gnu.org/licenses/>.*
- *                                                                                *
- **********************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Carlo Segato <brandon.ml@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "pidgin_emoticons.h"
 #include "kemoticonsprovider.h"
@@ -225,5 +213,5 @@ void PidginEmoticons::newTheme()
     fp.close();
 }
 
+#include "moc_pidgin_emoticons.cpp"
 #include "pidgin_emoticons.moc"
-
