@@ -1,20 +1,8 @@
-/**********************************************************************************
- *   Copyright (C) 2008 by Carlo Segato <brandon.ml@gmail.com>                    *
- *                                                                                *
- *   This library is free software; you can redistribute it and/or                *
- *   modify it under the terms of the GNU Lesser General Public                   *
- *   License as published by the Free Software Foundation; either                 *
- *   version 2.1 of the License, or (at your option) any later version.           *
- *                                                                                *
- *   This library is distributed in the hope that it will be useful,              *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of               *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU            *
- *   Lesser General Public License for more details.                              *
- *                                                                                *
- *   You should have received a copy of the GNU Lesser General Public             *
- *   License along with this library.  If not, see <http://www.gnu.org/licenses/>.*
- *                                                                                *
- **********************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Carlo Segato <brandon.ml@gmail.com>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "xmpp_emoticons.h"
 
@@ -25,7 +13,7 @@
 #include <QStandardPaths>
 #include <QMimeDatabase>
 
-#include <kpluginfactory.h>
+#include <KPluginFactory>
 
 K_PLUGIN_CLASS_WITH_JSON(XmppEmoticons, "emoticonstheme_xmpp.json")
 
@@ -219,5 +207,5 @@ void XmppEmoticons::newTheme()
     fp.close();
 }
 
+#include "moc_xmpp_emoticons.cpp"
 #include "xmpp_emoticons.moc"
-
